@@ -4,13 +4,10 @@ function (DataTimeSeries, order = c(p, d = NULL, q = NULL), seas = list(order =
 {
     if (is.null(type)) 
         stop("'type' must be one of  \"ARMA\", \"ARIMA\", \"SARIMA\", \"ARCH\", \"GARCH\",\"ARMAX\", \"ARIMAX\" or \"SARIMAX\"!")
-             
-  
     if (type != "ARMA" & type != "ARIMA" & type != "SARIMA" & 
         type != "ARCH" & type != "GARCH" & type != "ARMAX" & 
         type != "ARIMAX" & type != "SARIMAX") 
-        stop("Fuction PrintAIC can not comput this model!\n You should connect to Maintainer to develop\n            
-             code for the model by gmail <hongvietminh@gmail.com>")
+        stop("Fuction PrintAIC can not comput this model!\n You should connect to Maintainer to develop\n            \n             code for the model by gmail <hongvietminh@gmail.com>")
     sona <- function(x) {
         f <- x
         f[!is.na(f)] <- 0
